pub struct Id(/* private fields */);Expand description
Identifies a span within the context of a subscriber.
They are generated by Subscribers for each span as it is created, by
the new_span trait method. See the documentation for that method for
more information on span ID generation.
Implementations
Sourceimpl Id
impl Id
Sourcepub fn from_u64(u: u64) -> Id
pub fn from_u64(u: u64) -> Id
Constructs a new span ID from the given u64.
Note: Span IDs must be greater than zero.
Panics
- If the provided
u64is 0.
Sourcepub const fn from_non_zero_u64(id: NonZero<u64>) -> Id
pub const fn from_non_zero_u64(id: NonZero<u64>) -> Id
Constructs a new span ID from the given NonZeroU64.
Unlike Id::from_u64, this will never panic.
Sourcepub const fn into_non_zero_u64(&self) -> NonZero<u64>
pub const fn into_non_zero_u64(&self) -> NonZero<u64>
Returns the span’s ID as a NonZeroU64.